@@ -18,12 +18,15 @@ package inc::MBX::Alien::FLTK::Platform::Unix::Darwin;
                 ' -framework Carbon -framework Cocoa -framework ApplicationServices '
                 . $self->notes('ldflags')
         );
-        $self->notes(    # We know that Carbon is deprecated on OS X 10.4. To
-             # avoid hundreds of warnings we will temporarily disable 'deprecated'
-             # warnings on OS X.
-            cxxflags => ' -Wno-deprecated-declarations '
-                . $self->notes('cxxflags')
-        ) if $self->notes('os_ver') >= 800;
+        if ($self->notes('os_ver') >= 800) {
+
+            # We know that Carbon is deprecated on OS X 10.4. To avoid
+            # hundreds of warnings we will temporarily disable 'deprecated'
+            # warnings on OS X.
+            for my $type (qw[cxxflags cflags]) { }
+            $self->notes(  $type => ' -Wno-deprecated-declarations '
+                         . $self->notes($type));
+        }
 
         # Starting with 10.6 (Snow Leopard), OS X does not support Carbon
         # calls anymore. We patch this until we are completely Cocoa compliant
@@ -32,6 +35,7 @@ package inc::MBX::Alien::FLTK::Platform::Unix::Darwin;
         my ($ver, $rev) = ($ver_rev =~ m[^(\d+)\.(\d+)$]);
         if (($ver > 10) || (($ver == 10) && $rev >= 5)) {
             $self->notes(ldflags => $self->notes('ldflags') . ' -arch i386 ');
+            $self->notes(cflags  => $self->notes('cflags') . ' -arch i386 ');
             $self->notes(
                        cxxflags => $self->notes('cxxflags') . ' -arch i386 ');
         }
