@@ -3,7 +3,20 @@ package Alien::FLTK2;
     use strict;
     use warnings;
     use File::Spec::Functions qw[catdir rel2abs canonpath];
-    our $BASE = 0; our $SVN = 6970; our $DEV = -19; our $VERSION = sprintf('%d.%05d' . ($DEV ? (($DEV < 0 ? '' : '_') . '%03d') : ('')), $BASE, $SVN, abs $DEV);
+    our $BASE = 0; our $SVN = 6970; our $DEV = -20; our $VERSION = sprintf('%d.%05d' . ($DEV ? (($DEV < 0 ? '' : '_') . '%03d') : ('')), $BASE, $SVN, abs $DEV);
+    sub _git_rev {'fd41e31'}
+
+    sub _snapshot_mirrors {
+        return {
+            'Milky Way' => 'http://sankorobinson.com/fltk-2.0.x/snapshots/',
+
+            #'Github (temp)' => 'http://download.github.com/',
+            #'Github (gen)'  => 'http://waitdownload.github.com/'
+            'Github (perm)' => 'http://github.com/downloads/sanko/fltk-2.0.x/'
+
+                # waitdownload.github.com/sanko-fltk-2.0.x-fd41e31.tar.gz
+        };
+    }
 
     sub _md5 {
         return {gz  => '8159cabebbd1b5b774b277827aa4e030',
@@ -20,8 +33,8 @@ package Alien::FLTK2;
             ($self->{'basedir'})
                 = (grep { -d $_ && -f catdir($_, 'config.yml') }
                        map { rel2abs($_) } (
-                             eval { File::ShareDir::dist_dir('Alien-FLTK2') },
-                             'share', '../share', '../../share'
+                        'share', '../share', '../../share',
+                        eval { File::ShareDir::dist_dir('Alien-FLTK2') }
                        )
                 );
         }
@@ -61,17 +74,18 @@ package Alien::FLTK2;
 
     sub ldflags {    # XXX - Cache this
         my ($self, @args) = @_;
+        my $MSVC = 'Windows|MSVC' eq join '|', @{$self->config->{'platform'}};
 
         #
         my $libdir = shift->library_path();
 
         # Calculate needed libraries
         my $SHAREDSUFFIX
-            = $self->config->{'_a'} ? $self->config->{'_a'}
-            : $^O =~ '$MSWin32' ? '.a'
+            = $self->config->{'_a'}
+            ? $self->config->{'_a'}
+            : $^O =~ '$MSWin32' ? '.a'    # Even on MSVC... for now.
             :                     '.o';
-        my $LDSTATIC = sprintf '-L%s %s/libfltk2%s %s', $libdir, $libdir,
-            $SHAREDSUFFIX,
+        my $LDSTATIC = sprintf '%s/libfltk2%s %s', $libdir, $SHAREDSUFFIX,
             ($self->config->{'ldflags'} ? $self->config->{'ldflags'} : '');
         my $LDFLAGS = '-lfltk2 '
             . ($self->config->{'ldflags'} ? $self->config->{'ldflags'} : '');
@@ -98,9 +112,16 @@ package Alien::FLTK2;
             $LDSTATIC = sprintf '%s/libfltk2_images%s %s %s',
                 $libdir, $SHAREDSUFFIX, $img_libs, $LDSTATIC;
         }
-        return (  "-L$libdir "
-                . ((grep {m[static]} @args) ? $LDSTATIC : $LDFLAGS)
-                . ' -lsupc++');
+        my $ret
+            = (  " -L$libdir "
+               . (($MSVC || grep {m[static]} @args) ? $LDSTATIC : $LDFLAGS)
+               . ($MSVC ? '' : ' -lsupc++'));
+        if ($MSVC) {    # Oy...
+            $ret =~ s[-L([^\s]*)][/libpath:"$1"]g;
+            $ret =~ s[-l([^\s]*)][$1]g;
+            $ret =~ s[-D([^\s]+)][/D"$1"]g;
+        }
+        return $ret;
     }
 
     sub capabilities {
